@@ -53,6 +53,7 @@ public:
      */
     static KWindowSystem *self();
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the list of all toplevel windows currently managed by the
      * window manager in the order of creation. Please do not rely on
@@ -69,15 +70,22 @@ public:
      *  }
      * \endcode
      * @return the list of all toplevel windows
+     * @deprecated since 5.101, use KX11Extras::windows()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::windows() instead")
     static QList<WId> windows();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Test to see if @p id still managed at present.
      * @param id the window id to test
      * @return true if the window id is still managed
+     * @deprecated since 5.101, use KX11Extras::hasWId()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::hasWId() instead")
     static bool hasWId(WId id);
+#endif
 
 #if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -95,21 +103,30 @@ public:
     static KWindowInfo windowInfo(WId win, NET::Properties properties, NET::Properties2 properties2 = NET::Properties2());
 #endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the list of all toplevel windows currently managed by the
      * window manager in the current stacking order (from lower to
      * higher). May be useful for pagers.
      * @return the list of all toplevel windows in stacking order
+     * @deprecated since 5.101, use KX11Extras::stackingOrder()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::stackingOrder() instead")
     static QList<WId> stackingOrder();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the currently active window, or 0 if no window is active.
      * @return the window id of the active window, or 0 if no window is
      *  active
+     * @deprecated since 5.101, use KX11Extras::activeWindow()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::activeWindow() instead")
     static WId activeWindow();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Requests that window @p win is activated.
      *
@@ -135,8 +152,11 @@ public:
      * @param win the id of the window to make active
      * @param time X server timestamp of the user activity that
      *    caused this request
+     * @deprecated since 5.101, use KX11Extras::activateWindow() or KWindowSystem::activateWindow(QWindow *) instead
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::activateWindow() or KWindowSystem::activateWindow(QWindow *) instead")
     static void activateWindow(WId win, long time = 0);
+#endif
 
     /**
      * Requests that window @p win is activated.
@@ -168,6 +188,7 @@ public:
      */
     Q_INVOKABLE static void activateWindow(QWindow *window, long time = 0);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets window @p win to be the active window. Note that this
      * should be called only in special cases, applications
@@ -179,9 +200,13 @@ public:
      * @param win the id of the window to make active
      * @param time X server timestamp of the user activity that
      *    caused this request
+     * @deprecated since 5.101, use KX11Extras::forceActiveWindow()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::forceActiveWindow() instead")
     static void forceActiveWindow(WId win, long time = 0);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * When application finishes some operation and wants to notify
      * the user about it, it can call demandAttention(). Instead
@@ -190,34 +215,54 @@ public:
      * See also explanation in description of activateWindow().
      *
      * Note that it's usually better to use KNotifyClient.
+     * @deprecated since 5.101, use QWindow::alert() instead().
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use QWindow::alert()")
     static void demandAttention(WId win, bool set = true);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns true if a compositing manager is running (i.e. ARGB windows
      * are supported, effects will be provided, etc.).
+     * @deprecated since 5.101, use KX11Extras::compositingActive()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::compositingActive() instead")
     static bool compositingActive();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the current virtual desktop.
      * @return the current virtual desktop
+     * @deprecated since 5.101, use KX11Extras::currentDesktop()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::currentDesktop() instead")
     static int currentDesktop();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the number of virtual desktops.
      * @return the number of virtual desktops
+     * @deprecated since 5.101, use KX11Extras::numberOfDesktops()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::numberOfDesktops() instead")
     static int numberOfDesktops();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Convenience function to set the current desktop to @p desktop.
      * See NETRootInfo.
      * @param desktop the number of the new desktop
+     * @deprecated since 5.101, use KX11Extras::setCurrentDesktop()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setCurrentDesktop() instead")
     static void setCurrentDesktop(int desktop);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets window @p win to be present on all virtual desktops if @p
      * is true. Otherwise the window lives only on one single desktop.
@@ -225,17 +270,25 @@ public:
      * @param win the id of the window
      * @param b true to show the window on all desktops, false
      *          otherwise
+     * @deprecated since 5.101, use KX11Extras::setOnAllDesktops()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setOnAllDesktops() instead")
     static void setOnAllDesktops(WId win, bool b);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Moves window @p win to desktop @p desktop.
      *
      * @param win the id of the window
      * @param desktop the number of the new desktop
+     * @deprecated since 5.101, use KX11Extras::setOnDesktop()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setOnDesktop() instead")
     static void setOnDesktop(WId win, int desktop);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Moves window @p win to activities @p activities.
      *
@@ -244,8 +297,11 @@ public:
      *
      * @since 5.1
      * @see KWindowInfo::activities
+     * @deprecated since 5.101, use KX11Extras::setOnActivities()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setOnActivities() instead")
     static void setOnActivities(WId win, const QStringList &activities);
+#endif
 
     /**
      * Sets the parent window of @p subwindow to be @p mainwindow.
@@ -298,6 +354,8 @@ public:
     KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowInfo::groupLeader()")
     static WId groupLeader(WId window);
 #endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns an icon for window @p win.
      *
@@ -313,9 +371,13 @@ public:
      * @param scale if true the icon will be scaled to the desired size. Otherwise the
      *        icon will not be modified.
      * @return the icon of the window
+     * @deprecated since 5.101, use KX11Extras::icon()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::icon() instead")
     static QPixmap icon(WId win, int width = -1, int height = -1, bool scale = false);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Masks specifying from which sources to read an icon. They are tried from the best
      * until an icon is found.
@@ -330,6 +392,9 @@ public:
         ClassHint = 4, //!< load icon after getting name from the classhint
         XApp = 8, //!< load the standard X icon (last fallback)
     };
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * @overload
      *
@@ -343,9 +408,13 @@ public:
      * @param scale if true the icon will be scaled to the desired size. Otherwise the
      *        icon will not be modified.
      * @param flags OR-ed flags from the IconSource enum
+     * @deprecated since 5.101, use KX11Extras::icon()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::icon() instead")
     static QPixmap icon(WId win, int width, int height, bool scale, int flags);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * @overload
      *
@@ -368,16 +437,24 @@ public:
      * @param flags OR-ed flags from the IconSource enum
      * @param into the NETWinInfo to use for reading properties.
      * @since 5.7
+     * @deprecated since 5.101, use KX11Extras::icon()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::icon() instead")
     static QPixmap icon(WId win, int width, int height, bool scale, int flags, NETWinInfo *info);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets an @p icon and a  @p miniIcon on window @p win
      * @param win the id of the window
      * @param icon the new icon
      * @param miniIcon the new mini icon
+     * @deprecated since 5.101, use QWindow::setIcon() or QGuiApplication::setWindowIcon()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use QWindow::setIcon() or QGuiApplication::setWindowIcon()")
     static void setIcons(WId win, const QPixmap &icon, const QPixmap &miniIcon);
+#endif
+
     /**
      * Sets the type of window @p win to @p windowType.
      *
@@ -413,22 +490,31 @@ public:
      */
     static void clearState(WId win, NET::States state);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Minimizes the window with id @p win.
      * On X11 this follows the protocol described in ICCCM section 4.1.4.
      *
      * @param win The window to minimize
      * @see unminimizeWindow()
+     * @deprecated since 5.101, use KX11Extras::minimizeWindow() or QWindow::setState()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::minimizeWindow() or QWindow::setState() instead")
     static void minimizeWindow(WId win);
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Unminimizes the window with id @p win.
      * On X11 this follows the protocol described in ICCCM section 4.1.4.
      *
      * @param win The window to unminimize
      * @see minimizeWindow()
+     * @deprecated since 5.101, use KX11Extras::unminimizeWindow() or QWindow::setState()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::unminimizeWindow() or QWindow::setState() instead")
     static void unminimizeWindow(WId win);
+#endif
 
 #if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -454,30 +540,45 @@ public:
      */
     static void raiseWindow(WId win);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Lowers the given window. This call is only for pagers and similar
      * tools that represent direct user actions. Applications should not
      * use it, they should keep using QWidget::lower() or XLowerWindow()
      * if necessary.
+     *
+     * @deprecated since 5.101, no known users.
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "No known users.")
     static void lowerWindow(WId win);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * @internal
      * Returns true if the WM uses IconicState also for windows
      * on inactive virtual desktops.
+     *
+     * @deprecated since 5.101, internal.
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Internal")
     static bool icccmCompliantMappingState();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the workarea for the specified desktop, or the current
      * work area if no desktop has been specified.
      * @param desktop the number of the desktop to check, -1 for the
      *        current desktop
      * @return the size and position of the desktop
+     * @deprecated since 5.101, use KX11Extras::workArea()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::workArea() instead")
     static QRect workArea(int desktop = -1);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the workarea for the specified desktop, or the current
      * work area if no desktop has been specified. Excludes struts of
@@ -487,22 +588,33 @@ public:
      * @param desktop the number of the desktop to check, -1 for the
      *        current desktop
      * @return the size and position of the desktop
+     * @deprecated since 5.101, use KX11Extras::workArea()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::workArea() instead")
     static QRect workArea(const QList<WId> &excludes, int desktop = -1);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Returns the name of the specified desktop.
      * @param desktop the number of the desktop
      * @return the name of the desktop
+     * @deprecated since 5.101, use KX11Extras::desktopName()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::desktopName() instead")
     static QString desktopName(int desktop);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets the name of the specified desktop.
      * @param desktop the number of the desktop
      * @param name the new name for the desktop
+     * @deprecated since 5.101, use KX11Extras::setDesktopName()
      **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setDesktopName() instead")
     static void setDesktopName(int desktop, const QString &name);
+#endif
 
     /**
      * Returns the state of showing the desktop.
@@ -520,6 +632,7 @@ public:
      */
     static void setShowingDesktop(bool showing);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets user timestamp @p time on window @p win. The timestamp
      * is expressed as XServer time. If a window
@@ -527,8 +640,14 @@ public:
      * user action, it won't be activated after being shown.
      * The most common case is the special value 0 which means
      * not to activate the window after being shown.
+     *
+     * @deprecated since 5.101, use QX11Info::setAppUserTime().
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use QX11Info::setAppUserTime()")
     static void setUserTime(WId win, long time);
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets the strut of window @p win to @p left_width
      * ranging from @p left_start to @p left_end on the left edge,
@@ -550,6 +669,7 @@ public:
      * @param bottom_start starting x coordinate of the strut at the bottom edge
      * @param bottom_end ending x coordinate of the strut at the bottom edge
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setExtendedStrut() instead. In KF6 all arguments must be in the logical coordinates.")
     static void setExtendedStrut(WId win,
                                  int left_width,
                                  int left_start,
@@ -563,7 +683,9 @@ public:
                                  int bottom_width,
                                  int bottom_start,
                                  int bottom_end);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Convenience function for setExtendedStrut() that automatically makes struts
      * as wide/high as the screen width/height.
@@ -575,17 +697,25 @@ public:
      * @param top the top strut
      * @param bottom the bottom strut
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::setStrut() instead. In KF6 all arguments must be in the logical coordinates.")
     static void setStrut(WId win, int left, int right, int top, int bottom);
+#endif
+
     /**
      * Returns true if the WM announces which actions it allows for windows.
      */
     static bool allowedActionsSupported();
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Function that reads and returns the contents of the given text
      * property (WM_NAME, WM_ICON_NAME,...).
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::readNameProperty() instead")
     static QString readNameProperty(WId window, unsigned long atom);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 104)
     /**
      * Allows a window from another process to raise and activate itself.
      * Depending on the window manager, the grant may only be temporary,
@@ -602,20 +732,31 @@ public:
      *
      * @param pid if specified, the grant only applies to windows belonging to the
      *            specific process. By default, a value of -1 means all processes.
+     *
+     * @deprecated since 5.104, not implemented.
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 104, "Not implemented")
     static void allowExternalProcessWindowActivation(int pid = -1);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Sets whether the client wishes to block compositing (for better performance)
      * @since 4.7
+     * @deprecated since 5.101, no known users.
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "No known users")
     static void setBlockingCompositing(WId window, bool active);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * @internal
      * Returns true if viewports are mapped to virtual desktops.
      */
     static bool mapViewport();
+#endif
+
     /**
      * @internal
      * Returns mapped virtual desktop for the given position in the viewport.
@@ -631,13 +772,17 @@ public:
      * Returns topleft corner of the viewport area for the given mapped virtual desktop.
      */
     static QPoint desktopToViewport(int desktop, bool absolute);
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * @internal
      * @since 4.0.1
      * Checks the relative difference used to move a window will still be inside
      * valid desktop area.
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "No known users")
     static QPoint constrainViewportRelativePosition(const QPoint &pos);
+#endif
 
     /**
      * Updates the platform-specific startup id, if any.
@@ -677,6 +822,7 @@ public:
          **/
         Wayland,
     };
+    Q_ENUM(Platform)
     /**
      * Returns the Platform used by the QGuiApplication.
      * This method allows to check for the used windowing system in a cheap and reliable way.
@@ -710,7 +856,7 @@ public:
      * @param serial of the event that triggered the request
      * @param app_id identifier of the application that we are launching
      *
-     * @see currentSerial
+     * @see lastInputSerial
      * @since 5.83
      */
     Q_INVOKABLE static void requestXdgActivationToken(QWindow *win, uint32_t serial, const QString &app_id);
@@ -733,59 +879,96 @@ public:
 
 Q_SIGNALS:
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Switched to another virtual desktop.
      * @param desktop the number of the new desktop
+     * @deprecated since 5.101, use KX11Extras::currentDesktopChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::currentDesktopChanged()")
     void currentDesktopChanged(int desktop);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * A window has been added.
      * @param id the id of the window
+     * @deprecated since 5.101, use KX11Extras::windowAdded()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::windowAdded()")
     void windowAdded(WId id);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * A window has been removed.
      * @param id the id of the window that has been removed
+     * @deprecated since 5.101, use KX11Extras::windowRemoved()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::windowRemoved()")
     void windowRemoved(WId id);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Hint that \<Window> is active (= has focus) now.
      * @param id the id of the window that is active
+     * @deprecated since 5.101, use KX11Extras::activeWindowChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::activeWindowChanged()")
     void activeWindowChanged(WId id);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Desktops have been renamed.
+     * @deprecated since 5.101, use KX11Extras::desktopNamesChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::desktopNamesChanged()")
     void desktopNamesChanged();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * The number of desktops changed.
      * @param num the new number of desktops
+     * @deprecated since 5.101, use KX11Extras::numberOfDesktopsChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::numberOfDesktopsChanged()")
     void numberOfDesktopsChanged(int num);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * The workarea has changed.
+     * @deprecated since 5.101, use KX11Extras::workAreaChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::workAreaChanged()")
     void workAreaChanged();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Something changed with the struts, may or may not have changed
      * the work area. Usually just using the workAreaChanged() signal
      * is sufficient.
+     * @deprecated since 5.101, use KX11Extras::strutChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::strutChanged()")
     void strutChanged();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Emitted when the stacking order of the window changed. The new order
      * can be obtained with stackingOrder().
+     * @deprecated since 5.101, use KX11Extras::stackingOrderChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::stackingOrderChanged()")
     void stackingOrderChanged();
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * The window changed.
      *
@@ -796,8 +979,11 @@ Q_SIGNALS:
      * @param properties2 the properties2 that were modified
      *
      * @since 5.0
+     * @deprecated since 5.101, use KX11Extras::windowChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::windowChanged")
     void windowChanged(WId id, NET::Properties properties, NET::Properties2 properties2); // clazy:exclude=overloaded-signal
+#endif
 
 #if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -846,6 +1032,7 @@ Q_SIGNALS:
      */
     void showingDesktopChanged(bool showing);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 101)
     /**
      * Compositing was enabled or disabled.
      *
@@ -857,8 +1044,11 @@ Q_SIGNALS:
      * than test for it in a slot connected to this signal.
      *
      * @since 4.7.1
+     * @deprecated since 5.101, use KX11Extras::compositingChanged()
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 101, "Use KX11Extras::compositingChanged()")
     void compositingChanged(bool enabled);
+#endif
 
     /**
      * Activation @p token to pass to the client.
@@ -874,6 +1064,7 @@ protected:
 
 private:
     friend class KWindowSystemStaticContainer;
+    friend class KX11Extras;
 
     KWindowSystem()
     {
